PrinterColor class

Color applied on printer messages.

Defines ANSI color codes for terminal output.

Constructors

PrinterColor.blue()
Creates a blue PrinterColor.
const
PrinterColor.custom({required String schema})
Creates a PrinterColor with a custom ANSI color schema.
const
PrinterColor.cyan()
Creates a cyan PrinterColor.
const
PrinterColor.green()
Creates a green PrinterColor.
const
PrinterColor.magenta()
Creates a magenta PrinterColor.
const
PrinterColor.red()
Creates a red PrinterColor.
const
PrinterColor.yellow()
Creates a yellow PrinterColor.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema String
ANSI color schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited