Severity enum

Syslog severity levels.

These levels follow the standard syslog severity levels, ordered from most critical to least critical.

Inheritance
Available extensions

Values

emergency → const Severity

System is unusable.

Condition: A panic condition.

Level: 0

alert → const Severity

Action must be taken immediately.

Condition: Should be corrected immediately.

Level: 10

critical → const Severity

Critical conditions.

Condition: Hard device errors.

Level: 20

error → const Severity

Error conditions.

Level: 30

warning → const Severity

Warning conditions.

Condition: May indicate that an error will occur if action is not taken.

Level: 40

notice → const Severity

Normal but significant conditions.

Condition: Events that are unusual, but not error conditions.

Level: 50

informational → const Severity

Informational messages.

Condition: Normal operational messages that require no action.

Level: 60

debug → const Severity

Debug-level messages.

Condition: Information useful to developers for debugging the application.

Level: 70

Properties

atLeastError bool
Returns true if this severity is error or more critical.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
level int
Severity level as an integer.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Severity>
A constant List of the values in this enum, in order of their declaration.